.. _mendeleev:

************************************
Welcome to mendeleev's documentation
************************************

.. raw:: html

   <img src="_static/img/name_and_logo.png" alt="Logo" style="display: block;margin-left: auto;margin-right: auto;"> 


This package provides an API for accessing various properties of elements from
the periodic table of elements.

.. image:: _static/img/mendeleev_periodic_series.png
   :width: 1000px
   :align: center
   :alt: Periodic table


.. toctree::
   :caption: Contents

   Quick overview <quick>
   Installation <install>
   Tutorials <tutorials>
   Data <data>
   API Reference <code>
   License <license_link>

.. toctree::
   Changes <changes_link>


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
